@@ -19,13 +19,12 @@ use vars qw(@EXPORT @ISA $VERSION $AUTOLOAD);
 	     megahal_initial_greeting
 	     megahal_command
 	     megahal_do_reply
-	     megahal_learn
 	     megahal_output
 	     megahal_input
 	     megahal_cleanup);
 
 @ISA = qw(Exporter DynaLoader);
-$VERSION = '0.08_01';
+$VERSION = '0.04';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -89,25 +88,19 @@ sub new {
     return $self;
 }
 
-sub initial_greeting {
+sub initial_greeting() {
     my $self = shift;
 
     return megahal_initial_greeting();
 }
 
-sub do_reply {
+sub do_reply() {
     my ($self,$text) = @_;
 
     return megahal_do_reply($text,0);
 }
 
-sub learn {
-    my ($self,$text) = @_;
-
-    return megahal_learn($text,0);
-}
-
-sub _initialize {
+sub _initialize() {
     my $self = shift;
 
     megahal_initialize();
@@ -139,19 +132,17 @@ AI::MegaHAL - Perl interface to the MegaHAL natural language conversation simula
 
 =head1 SYNOPSIS
 
-    use AI::MegaHAL;
-    
-    my $megahal = AI::MegaHAL->new('Path'     => './',
-                               'Banner'   => 0,
-                               'Prompt'   => 0,
-                               'Wrap'     => 0,
-                               'AutoSave' => 0);
-    
-    my $text = $megahal->initial_greeting();
-    
-    $text = $megahal->do_reply($message);
-    
-    $megahal->learn($message);
+use AI::MegaHAL;
+
+$megahal = AI::new MegaHAL('Path'     => './',
+                           'Banner'   => 0,
+                           'Prompt'   => 0,
+                           'Wrap'     => 0,
+                           'AutoSave' => 0);
+
+$text = $megahal->initial_greeting();
+
+$text = $megahal->do_reply($message);
 
 =head1 DESCRIPTION
 
@@ -161,72 +152,45 @@ This package provides a Perl interface to the MegaHAL conversation simulator wri
 
 =head1 CONSTRUCTOR
 
-    $megahal = AI::MegaHAL->new('Path'     => './',
-                               'Banner'   => 0,
-                               'Prompt'   => 0,
-                               'Wrap'     => 0,
-                               'AutoSave' => 0);
+$megahal = new AI::MegaHAL('Path'     => './',
+                           'Banner'   => 0,
+                           'Prompt'   => 0,
+                           'Wrap'     => 0,
+                           'AutoSave' => 0);
 
-Creates a new C<AI::MegaHAL> object.  The object constructor can optionaly receive the following named parameters:
+Creates a new AI::MegaHAL object.  The object constructor can optionaly receive the following named parameters:
 
 =over 4
 
-=item C<Path> 
+=item B<Path> - The path to MegaHALs brain or training file (megahal.brn and megahal.trn respectively).  If 'Path' is not specified the current working directory is assumed.
 
-The path to MegaHALs brain or training file (megahal.brn and megahal.trn respectively).  If 'Path' is not specified the current working directory is assumed.
+=item B<Banner> - A flag which enables/disables the banner which is displayed when MegaHAL starts up.  The default is to disable the banner.
 
-=item C<Banner>
+=item B<Prompt> - A flag which enables/disables the prompt. This flag is only useful when MegaHAL is run interactively and is disabled by default.
 
-A flag which enables/disables the banner which is displayed when MegaHAL starts up.  The default is to disable the banner.
-
-=item C<Prompt> 
-
-A flag which enables/disables the prompt. This flag is only useful when MegaHAL is run interactively and is disabled by default.
-
-=item C<Wrap> 
-
-A flag which enables/disables word wrapping of MegaHALs responses when the lines exceed 80 characters in length.  The default is to disable word wrapping.
+=item B<Wrap> - A flag which enables/disables word wrapping of MegaHALs responses when the lines exceed 80 characters in length.  The default is to disable word wrapping.
 
 =back
 
 =head1 METHODS
 
-=head2 C<initial_greeting>
-
- $text = $megahal->initial_greeting();
+$text = $megahal->initial_greeting();
 
 Returns a string containing the initial greeting which is created by MegaHAL at startup.
 
-=head2 C<do_reply>
 
- $text = $megahal->do_reply($message);
+$text = $megahal->do_reply($message);
 
-Generates reply C<$text> to a given message C<$message>.
-
-=head2 C<learn>
-
- $megahal->learn($message);
-
-Learns from C<$message> without generating a response
+Generates reply $text to a given message $message.
 
 =head1 BUGS
 
 None known at this time.
 
-=head1 SEE ALSO
-
-POE::Component::AI::MegaHAL - IRC bot,
-
-L<http://teaandbiscuits.org.uk/drupal/node/65> - Irssi IRC bot,
-
-L<Hailo> - A pluggable Markov engine analogous to MegaHAL
-
 =head1 AUTHOR
 
-The Perl AI::MegaHAL interface was written by Cory Spencer <cspencer[at]sprocket.org>.
+The Perl AI::MegaHAL interface was written by Cory Spencer <cspencer@sprocket.org>
 
-Now maintained by Alexandr Ciornii <alexchorny[at]gmail.com>.
-
-MegaHAL was originally written by and is copyright Jason Hutchens <hutch[at]ciips.ee.uwa.edu.au>
+MegaHAL was originally written by and is copyright Jason Hutchens <hutch@ciips.ee.uwa.edu.au>
 
 =cut
